@@ -1,5 +1,6 @@
 import typing
 import discord
+from enum import IntEnum
 from discord.ext import commands
 from . import http
 from . import error
@@ -215,8 +216,8 @@ class SubcommandObject:
     :ivar name: Name of the subcommand.
     :ivar func: The coroutine of the command.
     :ivar description: Description of the command.
-    :ivar base_desc: Description of the base command.
-    :ivar sub_group_desc: Description of the subcommand_group.
+    :ivar base_description: Description of the base command.
+    :ivar subcommand_group_description: Description of the subcommand_group.
     :ivar auto_convert: Dictionary of the `auto_convert` of the command.
     :ivar allowed_guild_ids: List of the allowed guild id.
     """
@@ -226,8 +227,8 @@ class SubcommandObject:
         self.name = name.lower()
         self.func = sub["func"]
         self.description = sub["description"]
-        self.base_desc = sub["base_desc"]
-        self.sub_group_desc = sub["sub_group_desc"]
+        self.base_description = sub["base_desc"]
+        self.subcommand_group_description = sub["sub_group_desc"]
         self.auto_convert = sub["auto_convert"] if sub["auto_convert"] else {}
         self.allowed_guild_ids = sub["guild_ids"] if sub["guild_ids"] else []
         self.options = sub["api_options"] if sub["api_options"] else []
@@ -282,3 +283,17 @@ class CogSubcommandObject(SubcommandObject):
         :return: Coroutine
         """
         return self.func(self.cog, *args)
+
+
+class SlashCommandOptionType(IntEnum):
+    """
+    Equivalent of `ApplicationCommandOptionType <https://discord.com/developers/docs/interactions/slash-commands#applicationcommandoptiontype>`_  in the Discord API.
+    """
+    SUB_COMMAND = 1
+    SUB_COMMAND_GROUP = 2
+    STRING = 3
+    INTEGER = 4
+    BOOLEAN = 5
+    USER = 6
+    CHANNEL = 7
+    ROLE = 8
